pub enum VariantArg {
Show 13 variants Bool(i16), Bstr(Vec<u16>), LongLong(i64), Long(i32), Short(i16), Float(f32), Double(f64), UShort(u16), ULong(u32), ULongLong(u64), Int(i32), UInt(u32), SafeArray(SafeArray),
}
VariantArg is a type to simplify the conversion of rust types into variants that are used by windows APIs. Make sure to use the free_variant(s) functions if you convert the VariantArg to VARIANT.

Variants

Bool(i16)

Bstr(Vec<u16>)

LongLong(i64)

Long(i32)

Short(i16)

Float(f32)

Double(f64)

UShort(u16)

ULong(u32)

ULongLong(u64)

Int(i32)

UInt(u32)

SafeArray(SafeArray)