[][src]Enum win_variant::VariantArg

pub enum VariantArg {
    Bstr(Vec<u16>),
    Int(i32),
    UInt(u32),
}

VariantArg is a type to simplify the conversion of rust types into variants that are used by windows APIs. Make sure to use the free_variant(s) functions if you convert the VariantArg to VARIANT.

Variants

Bstr(Vec<u16>)
Int(i32)
UInt(u32)