[−][src]Enum win_variant::VariantArg
VariantArg is a type to simplify the conversion of rust types into variants that are used by windows APIs. Make sure to use the free_variant(s) functions if you convert the VariantArg to VARIANT.
Variants
Int(i32)UInt(u32)Trait Implementations
impl Debug for VariantArg[src]
impl From<i32> for VariantArg[src]
impl From<u32> for VariantArg[src]
impl Into<VARIANT> for VariantArg[src]
impl TryFrom<&'_ String> for VariantArg[src]
type Error = VariantArgError
The type returned in the event of a conversion error.
pub fn try_from(value: &String) -> Result<Self, Self::Error>[src]
impl TryFrom<&'_ str> for VariantArg[src]